pub enum Tags<'a> {
Long {
long: &'a str,
},
Short {
short: char,
},
LongShort {
long: &'a str,
short: char,
},
}Expand description
The set of tags that identify a particular option (-short, --long)
Variants
Long
This parameter uses only a long tag
Short
This parameter uses only a short tag
LongShort
This parameter uses both a long and short tag
Implementations