ParameterError

Enum ParameterError 

#[non_exhaustive]
pub enum ParameterError<'arg> { NeedArgument, FlagGotArgument(&'arg Arg), GotAdditionalInstance, ParseError { arg: &'arg Arg, message: String, }, ShouldBe { arg: &'arg Arg, expected: &'static [&'static str], }, Custom { message: String, }, }
An error trying to parse a parameter from a --flag or positional argument. These error are produced from the primitive types, like bools and strings and vectors.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


NeedArgument

This parameter needs an argument and didn’t get one



FlagGotArgument(&'arg Arg)

This parameter is flag; it got an argument and didn’t want one



GotAdditionalInstance

This parameter appeared more than once or too many times



ParseError

Failed to parse the argument

Fields

arg: &'arg Arg
message: String


ShouldBe

The argument should have been one of these (or, possibly, a case insensitive variation)

Fields

arg: &'arg Arg
expected: &'static [&'static str]


Custom

Something else went wrong

Fields

message: String