pub enum Repetition {
Single,
Multiple,
}Expand description
Information about whether a parameter may appear more than once on the command line. Note that a mandatory parameter must always appear at least once. Additionally note that some parameters allow subsequent instances to override earlier instances; these parameters as still considered non-repeating.
Variants
Single
This parameter should only appear at most once on the command line
Multiple
This parameter may appear more than once on the command line