ParameterSubgroup

Struct ParameterSubgroup 

pub struct ParameterSubgroup<'a> {
    pub description: Description<'a>,
    pub id: &'a str,
    pub title: &'a str,
    pub placeholder: &'a str,
    pub contents: UsageItems<'a>,
}
Details about a subgroup of additional parameters. Subgroups allow parameters to be nested, and additionally allow different kinds of parameter sets to coexist. For instance, a struct of global flags will use a subgroup to express any subcommands it wants.

Fields

description: Description<'a>

The description text for this group. Not usually printed.

id: &'a str

The identifier for this group. Not usually shown to the user in a usage message. I’d prefer to omit it entirely, but we use it to help look up the usage messages of individual subcommands (by traversing nested subgroups).

title: &'a str

When used as a group of items, the name of the group we show to the user. Usually Title Cased.

placeholder: &'a str

When used as a placeholder, the name of the group we show to the user. Usually SHOUTY_SNAKE_CASED. Generally only used to refer to a subcommand in a synopsis.

contents: UsageItems<'a>

The contents of this group.