DetectUnrecognized

Enum DetectUnrecognized 

pub enum DetectUnrecognized<A, E> {
    Unrecognized(A),
    Error(E),
}
An error type that assists state errors with propagating unrecognized arguments.

When a State doesn’t recognize an argument, it returns the argument it got as a function argument, so that it can be retried elsewhere. This enum provides a container for this function argument. This allows the caller of the state method to opt-in or opt-out of actually receiving this unused argument, depending on if it wants to retry it or not.

This type is mostly used by the debate derives.

Variants



Unrecognized(A)

This argument wasn’t recognized and can be retried



Error(E)

A different error occurred