NonEmpty

Struct NonEmpty 

pub struct NonEmpty<T, C> {
    pub first: T,
    pub rest: C,
}
PositionalParameter wrapper for collection types that structurally guarantees that at least one argument is present.

Collections can be empty, so their Parameter implementations return success if no values were present on the command line. Wrapping them in this type (for instance, NonEmpty<String, Vec<String>>) ensures that at least one argument is present

Fields

first: Trest: C

Implementations

Source

impl<T, C> NonEmpty<T, C>
where for<'a> &'a C: IntoIterator<Item = &'a T>,

Source

impl<T, C> NonEmpty<T, C>
where for<'a> &'a mut C: IntoIterator<Item = &'a mut T>,