pub trait FlagsList<'a> {
// Required methods
fn new(tags: Tags<'a>, placeholder: &'a str) -> Self;
fn add(&mut self, tags: Tags<'a>, placeholder: &'a str);
}Expand description
Errors sometimes need to be able to refer to a group of flags, guaranteeing at least one. This trait allows the error type to express which container it wants to use.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.