pub struct NonEmpty<T, C> {
pub first: T,
pub rest: C,
}Expand description
PositionalParameter wrapper for collection types that structurally
guarantees that at least one argument is present.
Collections can be empty, so their Parameter implementations return success
if no values were present on the command line. Wrapping them in this type (for
instance, NonEmpty<String, Vec<String>>) ensures that at least one argument
is present
Fields
first: Trest: CImplementations
Sourceimpl<T, C> NonEmpty<T, C>
impl<T, C> NonEmpty<T, C>
pub fn iter(&self) -> NonEmptyIter<<&C as IntoIterator>::IntoIter> ⓘ
Sourceimpl<T, C> NonEmpty<T, C>
impl<T, C> NonEmpty<T, C>
pub fn iter_mut(&mut self) -> NonEmptyIter<<&mut C as IntoIterator>::IntoIter> ⓘ